==> fbthrift-2025.04.28.00_0.darwin_10.ppc.tbz2: opt/local/lib/cmake/fbthrift/FBThriftTargets-macports.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "MacPorts".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "FBThrift::thrift1" for configuration "MacPorts"
set_property(TARGET FBThrift::thrift1 APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thrift1 PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/bin/thrift1"
  )

list(APPEND _cmake_import_check_targets FBThrift::thrift1 )
list(APPEND _cmake_import_check_files_for_FBThrift::thrift1 "${_IMPORT_PREFIX}/bin/thrift1" )

# Import target "FBThrift::compiler_ast" for configuration "MacPorts"
set_property(TARGET FBThrift::compiler_ast APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::compiler_ast PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libcompiler_ast.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::compiler_ast )
list(APPEND _cmake_import_check_files_for_FBThrift::compiler_ast "${_IMPORT_PREFIX}/lib/libcompiler_ast.a" )

# Import target "FBThrift::compiler_base" for configuration "MacPorts"
set_property(TARGET FBThrift::compiler_base APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::compiler_base PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libcompiler_base.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::compiler_base )
list(APPEND _cmake_import_check_files_for_FBThrift::compiler_base "${_IMPORT_PREFIX}/lib/libcompiler_base.a" )

# Import target "FBThrift::compiler_lib" for configuration "MacPorts"
set_property(TARGET FBThrift::compiler_lib APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::compiler_lib PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libcompiler_lib.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::compiler_lib )
list(APPEND _cmake_import_check_files_for_FBThrift::compiler_lib "${_IMPORT_PREFIX}/lib/libcompiler_lib.a" )

# Import target "FBThrift::compiler" for configuration "MacPorts"
set_property(TARGET FBThrift::compiler APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::compiler PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libcompiler.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::compiler )
list(APPEND _cmake_import_check_files_for_FBThrift::compiler "${_IMPORT_PREFIX}/lib/libcompiler.a" )

# Import target "FBThrift::whisker" for configuration "MacPorts"
set_property(TARGET FBThrift::whisker APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::whisker PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libwhisker.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::whisker )
list(APPEND _cmake_import_check_files_for_FBThrift::whisker "${_IMPORT_PREFIX}/lib/libwhisker.a" )

# Import target "FBThrift::shared" for configuration "MacPorts"
set_property(TARGET FBThrift::shared APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::shared PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libshared.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::shared )
list(APPEND _cmake_import_check_files_for_FBThrift::shared "${_IMPORT_PREFIX}/lib/libshared.a" )

# Import target "FBThrift::thriftannotation" for configuration "MacPorts"
set_property(TARGET FBThrift::thriftannotation APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thriftannotation PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthriftannotation.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thriftannotation )
list(APPEND _cmake_import_check_files_for_FBThrift::thriftannotation "${_IMPORT_PREFIX}/lib/libthriftannotation.a" )

# Import target "FBThrift::thrift-core" for configuration "MacPorts"
set_property(TARGET FBThrift::thrift-core APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thrift-core PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthrift-core.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thrift-core )
list(APPEND _cmake_import_check_files_for_FBThrift::thrift-core "${_IMPORT_PREFIX}/lib/libthrift-core.a" )

# Import target "FBThrift::concurrency" for configuration "MacPorts"
set_property(TARGET FBThrift::concurrency APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::concurrency PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libconcurrency.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::concurrency )
list(APPEND _cmake_import_check_files_for_FBThrift::concurrency "${_IMPORT_PREFIX}/lib/libconcurrency.a" )

# Import target "FBThrift::transport" for configuration "MacPorts"
set_property(TARGET FBThrift::transport APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::transport PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libtransport.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::transport )
list(APPEND _cmake_import_check_files_for_FBThrift::transport "${_IMPORT_PREFIX}/lib/libtransport.a" )

# Import target "FBThrift::async" for configuration "MacPorts"
set_property(TARGET FBThrift::async APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::async PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libasync.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::async )
list(APPEND _cmake_import_check_files_for_FBThrift::async "${_IMPORT_PREFIX}/lib/libasync.a" )

# Import target "FBThrift::runtime" for configuration "MacPorts"
set_property(TARGET FBThrift::runtime APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::runtime PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libruntime.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::runtime )
list(APPEND _cmake_import_check_files_for_FBThrift::runtime "${_IMPORT_PREFIX}/lib/libruntime.a" )

# Import target "FBThrift::ProtocolBench" for configuration "MacPorts"
set_property(TARGET FBThrift::ProtocolBench APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::ProtocolBench PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/bin/ProtocolBench"
  )

list(APPEND _cmake_import_check_targets FBThrift::ProtocolBench )
list(APPEND _cmake_import_check_files_for_FBThrift::ProtocolBench "${_IMPORT_PREFIX}/bin/ProtocolBench" )

# Import target "FBThrift::rpcmetadata" for configuration "MacPorts"
set_property(TARGET FBThrift::rpcmetadata APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::rpcmetadata PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/librpcmetadata.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::rpcmetadata )
list(APPEND _cmake_import_check_files_for_FBThrift::rpcmetadata "${_IMPORT_PREFIX}/lib/librpcmetadata.a" )

# Import target "FBThrift::thriftmetadata" for configuration "MacPorts"
set_property(TARGET FBThrift::thriftmetadata APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thriftmetadata PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthriftmetadata.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thriftmetadata )
list(APPEND _cmake_import_check_files_for_FBThrift::thriftmetadata "${_IMPORT_PREFIX}/lib/libthriftmetadata.a" )

# Import target "FBThrift::thriftfrozen2" for configuration "MacPorts"
set_property(TARGET FBThrift::thriftfrozen2 APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thriftfrozen2 PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthriftfrozen2.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thriftfrozen2 )
list(APPEND _cmake_import_check_files_for_FBThrift::thriftfrozen2 "${_IMPORT_PREFIX}/lib/libthriftfrozen2.a" )

# Import target "FBThrift::thrifttyperep" for configuration "MacPorts"
set_property(TARGET FBThrift::thrifttyperep APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thrifttyperep PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthrifttyperep.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thrifttyperep )
list(APPEND _cmake_import_check_files_for_FBThrift::thrifttyperep "${_IMPORT_PREFIX}/lib/libthrifttyperep.a" )

# Import target "FBThrift::thrifttype" for configuration "MacPorts"
set_property(TARGET FBThrift::thrifttype APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thrifttype PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthrifttype.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thrifttype )
list(APPEND _cmake_import_check_files_for_FBThrift::thrifttype "${_IMPORT_PREFIX}/lib/libthrifttype.a" )

# Import target "FBThrift::thriftanyrep" for configuration "MacPorts"
set_property(TARGET FBThrift::thriftanyrep APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thriftanyrep PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthriftanyrep.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thriftanyrep )
list(APPEND _cmake_import_check_files_for_FBThrift::thriftanyrep "${_IMPORT_PREFIX}/lib/libthriftanyrep.a" )

# Import target "FBThrift::thriftprotocol" for configuration "MacPorts"
set_property(TARGET FBThrift::thriftprotocol APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thriftprotocol PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthriftprotocol.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thriftprotocol )
list(APPEND _cmake_import_check_files_for_FBThrift::thriftprotocol "${_IMPORT_PREFIX}/lib/libthriftprotocol.a" )

# Import target "FBThrift::thriftcpp2" for configuration "MacPorts"
set_property(TARGET FBThrift::thriftcpp2 APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thriftcpp2 PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthriftcpp2.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thriftcpp2 )
list(APPEND _cmake_import_check_files_for_FBThrift::thriftcpp2 "${_IMPORT_PREFIX}/lib/libthriftcpp2.a" )

# Import target "FBThrift::serverdbginfo" for configuration "MacPorts"
set_property(TARGET FBThrift::serverdbginfo APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::serverdbginfo PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libserverdbginfo.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::serverdbginfo )
list(APPEND _cmake_import_check_files_for_FBThrift::serverdbginfo "${_IMPORT_PREFIX}/lib/libserverdbginfo.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> fbthrift-2025.05.26.00_0.darwin_10.ppc.tbz2: opt/local/lib/cmake/fbthrift/FBThriftTargets-macports.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "MacPorts".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "FBThrift::thrift1" for configuration "MacPorts"
set_property(TARGET FBThrift::thrift1 APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thrift1 PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/bin/thrift1"
  )

list(APPEND _cmake_import_check_targets FBThrift::thrift1 )
list(APPEND _cmake_import_check_files_for_FBThrift::thrift1 "${_IMPORT_PREFIX}/bin/thrift1" )

# Import target "FBThrift::compiler_ast" for configuration "MacPorts"
set_property(TARGET FBThrift::compiler_ast APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::compiler_ast PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libcompiler_ast.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::compiler_ast )
list(APPEND _cmake_import_check_files_for_FBThrift::compiler_ast "${_IMPORT_PREFIX}/lib/libcompiler_ast.a" )

# Import target "FBThrift::compiler_base" for configuration "MacPorts"
set_property(TARGET FBThrift::compiler_base APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::compiler_base PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libcompiler_base.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::compiler_base )
list(APPEND _cmake_import_check_files_for_FBThrift::compiler_base "${_IMPORT_PREFIX}/lib/libcompiler_base.a" )

# Import target "FBThrift::compiler_lib" for configuration "MacPorts"
set_property(TARGET FBThrift::compiler_lib APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::compiler_lib PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libcompiler_lib.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::compiler_lib )
list(APPEND _cmake_import_check_files_for_FBThrift::compiler_lib "${_IMPORT_PREFIX}/lib/libcompiler_lib.a" )

# Import target "FBThrift::compiler" for configuration "MacPorts"
set_property(TARGET FBThrift::compiler APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::compiler PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libcompiler.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::compiler )
list(APPEND _cmake_import_check_files_for_FBThrift::compiler "${_IMPORT_PREFIX}/lib/libcompiler.a" )

# Import target "FBThrift::whisker" for configuration "MacPorts"
set_property(TARGET FBThrift::whisker APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::whisker PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libwhisker.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::whisker )
list(APPEND _cmake_import_check_files_for_FBThrift::whisker "${_IMPORT_PREFIX}/lib/libwhisker.a" )

# Import target "FBThrift::common" for configuration "MacPorts"
set_property(TARGET FBThrift::common APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::common PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libcommon.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::common )
list(APPEND _cmake_import_check_files_for_FBThrift::common "${_IMPORT_PREFIX}/lib/libcommon.a" )

# Import target "FBThrift::thriftannotation" for configuration "MacPorts"
set_property(TARGET FBThrift::thriftannotation APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thriftannotation PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthriftannotation.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thriftannotation )
list(APPEND _cmake_import_check_files_for_FBThrift::thriftannotation "${_IMPORT_PREFIX}/lib/libthriftannotation.a" )

# Import target "FBThrift::thrift-core" for configuration "MacPorts"
set_property(TARGET FBThrift::thrift-core APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thrift-core PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthrift-core.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thrift-core )
list(APPEND _cmake_import_check_files_for_FBThrift::thrift-core "${_IMPORT_PREFIX}/lib/libthrift-core.a" )

# Import target "FBThrift::concurrency" for configuration "MacPorts"
set_property(TARGET FBThrift::concurrency APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::concurrency PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libconcurrency.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::concurrency )
list(APPEND _cmake_import_check_files_for_FBThrift::concurrency "${_IMPORT_PREFIX}/lib/libconcurrency.a" )

# Import target "FBThrift::transport" for configuration "MacPorts"
set_property(TARGET FBThrift::transport APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::transport PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libtransport.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::transport )
list(APPEND _cmake_import_check_files_for_FBThrift::transport "${_IMPORT_PREFIX}/lib/libtransport.a" )

# Import target "FBThrift::async" for configuration "MacPorts"
set_property(TARGET FBThrift::async APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::async PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libasync.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::async )
list(APPEND _cmake_import_check_files_for_FBThrift::async "${_IMPORT_PREFIX}/lib/libasync.a" )

# Import target "FBThrift::runtime" for configuration "MacPorts"
set_property(TARGET FBThrift::runtime APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::runtime PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libruntime.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::runtime )
list(APPEND _cmake_import_check_files_for_FBThrift::runtime "${_IMPORT_PREFIX}/lib/libruntime.a" )

# Import target "FBThrift::ProtocolBench" for configuration "MacPorts"
set_property(TARGET FBThrift::ProtocolBench APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::ProtocolBench PROPERTIES
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/bin/ProtocolBench"
  )

list(APPEND _cmake_import_check_targets FBThrift::ProtocolBench )
list(APPEND _cmake_import_check_files_for_FBThrift::ProtocolBench "${_IMPORT_PREFIX}/bin/ProtocolBench" )

# Import target "FBThrift::rpcmetadata" for configuration "MacPorts"
set_property(TARGET FBThrift::rpcmetadata APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::rpcmetadata PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/librpcmetadata.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::rpcmetadata )
list(APPEND _cmake_import_check_files_for_FBThrift::rpcmetadata "${_IMPORT_PREFIX}/lib/librpcmetadata.a" )

# Import target "FBThrift::thriftmetadata" for configuration "MacPorts"
set_property(TARGET FBThrift::thriftmetadata APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thriftmetadata PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthriftmetadata.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thriftmetadata )
list(APPEND _cmake_import_check_files_for_FBThrift::thriftmetadata "${_IMPORT_PREFIX}/lib/libthriftmetadata.a" )

# Import target "FBThrift::thriftfrozen2" for configuration "MacPorts"
set_property(TARGET FBThrift::thriftfrozen2 APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thriftfrozen2 PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthriftfrozen2.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thriftfrozen2 )
list(APPEND _cmake_import_check_files_for_FBThrift::thriftfrozen2 "${_IMPORT_PREFIX}/lib/libthriftfrozen2.a" )

# Import target "FBThrift::thrifttyperep" for configuration "MacPorts"
set_property(TARGET FBThrift::thrifttyperep APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thrifttyperep PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthrifttyperep.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thrifttyperep )
list(APPEND _cmake_import_check_files_for_FBThrift::thrifttyperep "${_IMPORT_PREFIX}/lib/libthrifttyperep.a" )

# Import target "FBThrift::thrifttype" for configuration "MacPorts"
set_property(TARGET FBThrift::thrifttype APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thrifttype PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthrifttype.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thrifttype )
list(APPEND _cmake_import_check_files_for_FBThrift::thrifttype "${_IMPORT_PREFIX}/lib/libthrifttype.a" )

# Import target "FBThrift::thriftanyrep" for configuration "MacPorts"
set_property(TARGET FBThrift::thriftanyrep APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thriftanyrep PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthriftanyrep.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thriftanyrep )
list(APPEND _cmake_import_check_files_for_FBThrift::thriftanyrep "${_IMPORT_PREFIX}/lib/libthriftanyrep.a" )

# Import target "FBThrift::thriftprotocol" for configuration "MacPorts"
set_property(TARGET FBThrift::thriftprotocol APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thriftprotocol PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthriftprotocol.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thriftprotocol )
list(APPEND _cmake_import_check_files_for_FBThrift::thriftprotocol "${_IMPORT_PREFIX}/lib/libthriftprotocol.a" )

# Import target "FBThrift::thriftcpp2" for configuration "MacPorts"
set_property(TARGET FBThrift::thriftcpp2 APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::thriftcpp2 PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libthriftcpp2.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::thriftcpp2 )
list(APPEND _cmake_import_check_files_for_FBThrift::thriftcpp2 "${_IMPORT_PREFIX}/lib/libthriftcpp2.a" )

# Import target "FBThrift::serverdbginfo" for configuration "MacPorts"
set_property(TARGET FBThrift::serverdbginfo APPEND PROPERTY IMPORTED_CONFIGURATIONS MACPORTS)
set_target_properties(FBThrift::serverdbginfo PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_MACPORTS "CXX"
  IMPORTED_LOCATION_MACPORTS "${_IMPORT_PREFIX}/lib/libserverdbginfo.a"
  )

list(APPEND _cmake_import_check_targets FBThrift::serverdbginfo )
list(APPEND _cmake_import_check_files_for_FBThrift::serverdbginfo "${_IMPORT_PREFIX}/lib/libserverdbginfo.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
